package main

import (
	"testing"

	"github.com/stretchr/testify/assert"
)

func TestConfig(t *testing.T) {
	t.Parallel()

	var configData = []byte(`
salt: 'xXxN4CLxXx'

authors:
  read@stick.rocketnine.space: 'Read Access'
  check@stick.rocketnine.space: 'Check Access'
  write@stick.rocketnine.space: 'Write Access'

notebooks:
  Test Notebook A:
    repo: /home/stick/repo/a
    serve:
      - read@stick.rocketnine.space: read
      - write@stick.rocketnine.space: write
  Test Notebook B:
    repo: /home/stick/repo/b
    serve:
      - check@stick.rocketnine.space: check
      - write@stick.rocketnine.space
`)

	c, err := ReadConfigData(configData)
	if err != nil {
		t.Errorf("failed to load config data: %+v", err)
	}

	assert.Equal(t, false, c.Debug)
	assert.Equal(t, "xXxN4CLxXx", c.Salt)
	assert.ElementsMatch(t, []*AuthorConfig{
		{Email: "read@stick.rocketnine.space", Name: "Read Access"},
		{Email: "check@stick.rocketnine.space", Name: "Check Access"},
		{Email: "write@stick.rocketnine.space", Name: "Write Access"}},
		c.Authors)
	assert.ElementsMatch(t, []*NotebookConfig{
		{Label: "Test Notebook A", Repo: "/home/stick/repo/a", Serve: map[string]int{"read@stick.rocketnine.space": AuthorAccessRead, "write@stick.rocketnine.space": AuthorAccessWrite}},
		{Label: "Test Notebook B", Repo: "/home/stick/repo/b", Serve: map[string]int{"check@stick.rocketnine.space": AuthorAccessCheck, "write@stick.rocketnine.space": AuthorAccessWrite}}},
		c.Notebooks)
}
