package main

import (
	"fmt"
	"log"
	"math/rand"
	"os"
	"time"

	"github.com/pkg/errors"
	"github.com/urfave/cli"
)

var (
	stick *Stick
)

func main() {
	rand.Seed(time.Now().UTC().UnixNano())

	app := cli.NewApp()

	app.Name = "stick"
	app.Usage = "Shareable Git-backed Markdown-formatted notes"

	app.Version = ""
	app.HideVersion = true

	configPath := ""
	debug := false

	app.Flags = []cli.Flag{
		cli.StringFlag{
			Name:        "config",
			Usage:       "configuration file",
			EnvVar:      "STICK_CONFIG",
			Value:       "~/.config/stick/stick.yml",
			Destination: &configPath,
		},
		cli.BoolFlag{
			Name:        "debug",
			Usage:       "run in debug mode",
			EnvVar:      "STICK_DEBUG",
			Destination: &debug,
		},
	}

	app.Commands = []cli.Command{
		{
			Name:    "init",
			Aliases: []string{"i"},
			Usage:   "create a notebook",
			Action: func(c *cli.Context) error {
				Initialize(configPath, debug)

				path := c.Args().First()
				if path == "" {
					fmt.Println("USAGE: stick init <path> [cloneurl]")
					return nil
				}

				cloneURL := c.Args().Get(1)

				_, err := InitializeRepository(path, cloneURL)
				if err != nil {
					panic(errors.Wrap(err, "failed to initialize notebook"))
				}

				fmt.Println("notebook initialized")
				return nil
			},
		},
		{
			Name:    "resolve",
			Aliases: []string{"r"},
			Usage:   "resolve a merge conflict",
			Action: func(c *cli.Context) error {
				Initialize(configPath, debug)

				path := c.Args().First()
				if path == "" {
					fmt.Println("USAGE: stick resolve <path>")
					return nil
				}

				// TODO: initialize editor to resolve conflict

				return nil
			},
		},
		{
			Name:    "serve",
			Aliases: []string{"s"},
			Usage:   "serve shared notebooks",
			Action: func(c *cli.Context) error {
				Initialize(configPath, debug)

				address := c.Args().First()
				if stick.Config.Serve == "" && address == "" {
					fmt.Println("USAGE: stick serve <[address]:[port]>")
					return nil
				} else if address != "" {
					stick.Config.Serve = address
				}

				registerSignalHandlers()

				log.Printf("serving shared notebooks on %s", stick.Config.Serve)
				serveWeb()

				return nil
			},
		},
	}

	err := app.Run(os.Args)
	CheckError(err)
}
