const ASSET_CACHE = 'stick-assets-v1';

const ASSETS = [
    '/',
    '/assets/dexie.js',
    '/assets/jquery.js',
    '/assets/marked.min.js',
    '/assets/normalize.css',
    '/assets/stick.css',
    '/assets/stick.js',
];

self.addEventListener('install', function (e) {
    console.log('[ServiceWorker] Installing...');
    e.waitUntil(
        caches.open(ASSET_CACHE).then(cache => cache.addAll(ASSETS)).then(self.skipWaiting())
    );
});

self.addEventListener('activate', event => {
    console.log('[ServiceWorker] Activating...');
    const currentCaches = [ASSET_CACHE];
    event.waitUntil(
        caches.keys().then(cacheNames => {
            return cacheNames.filter(cacheName => !currentCaches.includes(cacheName));
        }).then(cachesToDelete => {
            return Promise.all(cachesToDelete.map(cacheToDelete => {
                return caches.delete(cacheToDelete);
            }));
        }).then(() => self.clients.claim())
    );
});

self.addEventListener('fetch', function (event) {
    event.respondWith(
        caches.match(event.request).then(function (response) {
            return response || fetch(event.request);
        })
    );
});
